@@ -242,19 +242,7 @@ config_zun_dashboard
 
 if settings_changed; then
     ${MANAGE_PY} collectstatic --noinput --clear
-    compress_ok="false"
-    for a in 1 2 3 4 5; do
-        if ${MANAGE_PY} compress --force 2>&1 > /dev/null; then
-            compress_ok="true"
-            break
-        else
-            echo "attempt ${a} failed"
-        fi
-    done
-    if [ "$compress_ok" = "false" ]; then
-        echo "The compress operation failed after 5 attempts."
-        exit 1
-    fi
+    ${MANAGE_PY} compress --force
     settings_bundle | md5sum > $HASH_PATH
 fi
 
