@@ -7,4 +7,4 @@ if [[ $(stat -c %a /var/log/kolla/nova) != "755" ]]; then
     chmod 755 /var/log/kolla/nova
 fi
 
-source /usr/local/bin/kolla_nova_extend_start
+. /usr/local/bin/kolla_nova_extend_start
